@@ -702,13 +702,18 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
     unpublishLayer = function(ws, ds, lyr){
       self$INFO(sprintf("Unpublishing layer '%s'", lyr))
       unpublished <- FALSE
-      lyrDeleted <- self$deleteLayer(lyr)
-      ftDeleted <- self$deleteFeatureType(ws, ds, lyr)
-      if(ftDeleted){
-          unpublished <- TRUE
-          self$INFO("Successfully unpublished layer!")
+      layer <- self$getLayer(lyr)
+      if(is(layer, "GSLayer")){
+        lyrDeleted <- self$deleteLayer(lyr)
+      }
+      featureType <- self$getFeatureType(ws, ds, lyr)
+      if(is(featureType, "GSFeatureType")){
+        ftDeleted <- self$deleteFeatureType(ws, ds, lyr)
+        if(ftDeleted){
+            unpublished <- TRUE
+            self$INFO("Successfully unpublished layer!")
+        }
       }
-      if(!unpublished) self$ERROR("Error while unpublishing layer")
       return(unpublished)
     },
     
